import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs/Observable';
import { MsRecursos } from '@app/modelo';
import { environment } from '@env/environment';

@Injectable()
export class MsRecursoService {

  constructor(private httpClient: HttpClient) { }

  	public subirRecurso (recurso: MsRecursos): Observable<MsRecursos> {
		return this.httpClient.put<MsRecursos>(
			`${environment.rest_url}mediaserver/${environment.ciaopr}`, recurso);
	}

	public subirArchivo (recurso: MsRecursos): Observable<MsRecursos> {
		return this.httpClient.put<MsRecursos>(
			`${environment.rest_url}mediaserver/subir_arch/${environment.ciaopr}`, recurso);
	}

	public subirArchivos (recursos: MsRecursos[]): Observable<MsRecursos[]> {
		return this.httpClient.put<MsRecursos[]>(
			`${environment.rest_url}mediaserver/subir_archivos/${environment.ciaopr}`, recursos);
	}

	public getDirectorios (ciaopr: string): Observable<Response> {
		return this.httpClient.get<Response>(
			`${environment.rest_url}mediaserver/directorio/${environment.ciaopr}`);
	}

	public consultaRecursos(ciaopr: string, nrorecurso: number, 
							 fecha_creacion_desde: string, 
							 fecha_creacion_hasta: string,
							 busqueda_string: string, 
							 reg_cantidad: number,
							 pagina: number): Observable<Response> {
		let urlrequest = environment.rest_url;
		urlrequest += 'mediaserver/list/' + environment.ciaopr;
		let w:any = {};

		w.ciaopr = environment.ciaopr;

		if (nrorecurso) {
			w.nrorecurso = nrorecurso;
		}
		if(fecha_creacion_desde){
			w.fecha_creacion_desde = fecha_creacion_desde;
		}
		if(fecha_creacion_hasta){
			w.fecha_creacion_hasta = fecha_creacion_hasta;
		}
		if(busqueda_string){
			w.busqueda_string = busqueda_string;
		}
		if(reg_cantidad) {
			w.reg_cantidad = reg_cantidad;
		}
		if(pagina) {
			w.pagina = pagina;
		}
		
		return this.httpClient.post<Response>(urlrequest, w);
	}


	public obtenerRecursoMediaHash(ciaopr: string, hash: string, 
		reg_cantidad: number,
		pagina: number): Observable<Response> {
		
		let urlrequest = environment.rest_url;
		urlrequest += 'mediaserver/' + environment.ciaopr;
		
		
		if(hash){
			urlrequest+='?hash='+ hash;
		}

		if(reg_cantidad) {
			urlrequest+='&reg_cant='+ reg_cantidad;
		}
		if(pagina) {
			urlrequest+='&pagina='+ pagina;
		}
		return this.httpClient.get<Response>(urlrequest);
	}

	public guardarModsRecurso(ciaopr:string,
		nrorecurso:number,
		titulo:string,
		descripcion:string,
		tags:string): Observable<Response> {
	
			let urlrequest = environment.rest_url;
			urlrequest += 'mediaserver/actualizar/'+ciaopr+"/"+nrorecurso;
			let w:any = {}

			w.ciaopr = ciaopr;
			w.nrorecurso = nrorecurso;
			w.titulo1 = titulo;
			w.descripcion1 = descripcion;
			w.tags = tags;

			return this.httpClient.put<Response>(urlrequest, w); 
		}

}