import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { environment } from '@env/environment';
import { Observable } from 'rxjs/Observable';
import { Response } from '@app/modelo/dto/response';
import { Nota } from '@app/modelo';
import { NotaConsulta } from '@app/modelo';
import { SegAuthorityUser } from '@app/modelo';

@Injectable()
export class NotaService {

    constructor(private httpClient: HttpClient) { }

    public buscarNotasParams(ciaopr: string,
							w: NotaConsulta,
							pagina = 1,
							cant_registros: number = environment.cat_regs_x_paginas): Observable<Response> {
        let urlrequest = environment.rest_url;

		urlrequest += 'nota/consulta/' + environment.ciaopr;
        urlrequest += '?cant_registros=' + cant_registros;
        urlrequest += '&pagina=' + pagina;

        return this.httpClient.post<Response>(urlrequest, w);
    }

    public listarNotas(nota_consulta: NotaConsulta): Observable<Response> {

        nota_consulta.pagina = nota_consulta.pagina ?  nota_consulta.pagina : 1;
        nota_consulta.reg_cantidad = nota_consulta.reg_cantidad ?
            nota_consulta.reg_cantidad : environment.cat_regs_x_paginas;

        return this.httpClient.post<Response>(
			`${environment.rest_url}nota/list/${environment.ciaopr}`, nota_consulta);
    }

    public buscarNotaPorID(notaId: string): Observable<Response>{
        let urlrequest = environment.rest_url;

        urlrequest += 'nota/'+ environment.ciaopr;
        urlrequest += '/'+ notaId;

        return this.httpClient.get<Response>(urlrequest);
    }
    
    public buscarNotaPorNronota2(nronota2: string): Observable<Response>{
        let urlrequest = environment.rest_url;

        urlrequest += 'nota/nronota2/'+ environment.ciaopr;
        urlrequest += '/'+ nronota2;

        return this.httpClient.get<Response>(urlrequest);
    }
	
	public incluirNota(nota: Nota): Observable<Response> {
        let urlrequest: string;
        urlrequest = environment.rest_url +
                    'nota/' + environment.ciaopr;

        return this.httpClient.post<Response>(urlrequest, nota);
    }

	public modificarNota(nota: Nota): Observable<Response> {
        let urlrequest: string;
        urlrequest = environment.rest_url +
                    'nota/' + environment.ciaopr;
        urlrequest += '/' + nota.nota_uuid;

        return this.httpClient.put<Response>(urlrequest, nota);
    }
    
    public modificarNotaMAM(nota: Nota): Observable<Response> {
        let urlrequest: string;
        urlrequest = environment.rest_url +
                    'nota/mam/' + environment.ciaopr;
        urlrequest += '/' + nota.nota_uuid;

        return this.httpClient.put<Response>(urlrequest, nota);
    }

    public aprobarDesaprobarNota(nota: Nota): Observable<Response> {
        let urlrequest: string;
        urlrequest = environment.rest_url +
                    'nota/aprobar_desaprobar/'+ environment.ciaopr;
        
        return this.httpClient.put<Response>(urlrequest, nota);
    }

     public tienePermiso(segAuthUser: SegAuthorityUser): Observable<Response> {
        let urlrequest: string;
        urlrequest = environment.rest_url +
                    'nota/modifica_nota_act/'+ environment.ciaopr;
        
        return this.httpClient.post<Response>(urlrequest, segAuthUser);
    }

    public creaOrdenNotas(portadacod: string): Observable<any> {
        let urlrequest: string;
        urlrequest = environment.rest_url +
                    'nota/ordena_notas/' + environment.ciaopr + '/' + portadacod;
        return this.httpClient.post<Response>(urlrequest, null);
    }
}
