import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs/Observable';
import { Pagina, PaginaConsulta, BloqueDef, PortadaVarianteBloqueDef } from '@app/modelo';
import { environment } from '@env/environment';
import * as moment from 'moment';

@Injectable()
export class PaginaService {

    constructor(private httpClient: HttpClient) { }

    public obtenerPagina (seccioncod: string): Observable<Pagina> {
        return this.httpClient.get<Pagina>(`${environment.rest_url}pagina/${environment.ciaopr}/${seccioncod}`);
    }

    public crearPagina (pagina: Pagina): Observable<Pagina> {
        return this.httpClient.post<Pagina>(
			`${environment.rest_url}pagina/${environment.ciaopr}`, pagina);
	}

	public listarPaginas (pagina_consulta: PaginaConsulta): Observable<Pagina[]> {
		return this.httpClient.post<Pagina[]>(
			`${environment.rest_url}pagina/list/${environment.ciaopr}`, pagina_consulta);
	}
	
	public obtenerPaginaXId(portadacod: string) : Observable<Pagina> {
		return this.httpClient.get<Pagina>(
			`${environment.rest_url}pagina/id/${environment.ciaopr}/${portadacod}`);
	}
    
    public eliminar(portadacod: string): Observable<any> {
        return this.httpClient.delete(`${environment.rest_url}pagina/id/${environment.ciaopr}/${portadacod}`);
	}
	
	public modificarPagina(pagina: Pagina): Observable<Pagina>{
		return this.httpClient.put<Pagina>(
			`${environment.rest_url}pagina/${environment.ciaopr}`, pagina);
	}

	public modifTituloVariantesBloq(ciaopr: string = environment.ciaopr,
		bloque:PortadaVarianteBloqueDef): Observable<Response> {
		let urlrequest = environment.rest_url;
		urlrequest += 'pagina/mod_titulo/' + environment.ciaopr;

  		return this.httpClient.put<Response>(urlrequest,bloque);
 	}
    
    public crearModificarPaginaConOrden (pagina: Pagina): Observable<Pagina> {
		return this.httpClient.post<Pagina>(
			`${environment.rest_url}pagina/crear_modificar_con_orden/${environment.ciaopr}`, pagina);
	}
}